# API Reference


## Storage

```{eval-rst}
.. autoclass:: pangeo_forge.storage.FSSpecTarget
    :members:
```

```{eval-rst}
.. autoclass:: pangeo_forge.storage.FlatFSSpecTarget
    :members:
    :show-inheritance:
```

```{eval-rst}
.. autoclass:: pangeo_forge.storage.CacheFSSpecTarget
    :members:
    :show-inheritance:
```

## Recipes

```{eval-rst}
.. autoclass:: pangeo_forge.recipe.BaseRecipe
    :members:
```

```{eval-rst}
.. autoclass:: pangeo_forge.recipe.NetCDFtoZarrRecipe
    :members:
```

```{eval-rst}
.. autoclass:: pangeo_forge.recipe.NetCDFtoZarrSequentialRecipe
    :show-inheritance:
```

```{eval-rst}
.. autoclass:: pangeo_forge.recipe.NetCDFtoZarrMultiVarSequentialRecipe
    :show-inheritance:
```

## Patterns

```{eval-rst}
.. autoclass:: pangeo_forge.patterns.VariableSequencePattern
    :members:
```

## Executors

```{eval-rst}
.. autoclass:: pangeo_forge.executors.PythonPipelineExecutor
    :members:
```

```{eval-rst}
.. autoclass:: pangeo_forge.executors.DaskPipelineExecutor
    :members:
```

```{eval-rst}
.. autoclass:: pangeo_forge.executors.PrefectPipelineExecutor
    :members:
```
